@@ -1,8 +1,6 @@
-from dozent.main import Dozent
-
 from dozent.catch_thread_exceptions import install as _catch_thread_exceptions
-from dozent.preprocess import Preprocess
+from dozent.dozent import Dozent
 
 _catch_thread_exceptions()
 
-__all__ = ['Dozent', 'Preprocess']
+__all__ = ["Dozent"]
